@@ -1,6 +1,6 @@
-# episoder, http://code.ott.net/projects/episoder
+# episoder, http://cockroach.github.io/episoder/
 #
-# Copyright (C) 2004-2013 Stefan Ott. All rights reserved.
+# Copyright (C) 2004-2014 Stefan Ott. All rights reserved.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ class Episode(object):
 		self.season = int(season)
 		self.episode = int(episode)
 		self.airdate = date
-		self.prodnum = str(prodnum)
+		self.prodnum = unicode(prodnum)
 		self.total = int(total)
 		self.show_id = self._show.show_id
 
