@@ -1,6 +1,6 @@
-# episoder, http://code.ott.net/projects/episoder
+# episoder, http://cockroach.github.io/episoder/
 #
-# Copyright (C) 2004-2013 Stefan Ott. All rights reserved.
+# Copyright (C) 2004-2014 Stefan Ott. All rights reserved.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -305,7 +305,7 @@ class ConsoleRenderer(object):
 		string = string.replace('%epnum', "%02d" % episode.episode)
 		string = string.replace('%eptitle', unicode(episode.title))
 		string = string.replace('%totalep', str(episode.total))
-		string = string.replace('%prodnum', str(episode.prodnum))
+		string = string.replace('%prodnum', unicode(episode.prodnum))
 		print ("%s%s%s" % (color, string.encode('utf8'), endColor))
 
 
